@@ -15,7 +15,6 @@ import apparmor
 import errno
 import json
 import os
-import re
 import shutil
 import sys
 import tempfile
@@ -69,7 +68,7 @@ def load_profile(profile, parser="/sbin/apparmor_parser", args=['-r', '--write-c
     command.append(profile)
     rc, output = easyprof.cmd(command)
     if rc != 0:
-         raise AppArmorException("policy load failed with errno %d: %s" %(rc, output))
+        raise AppArmorException("policy load failed with errno %d: %s" %(rc, output))
     return (rc, output)
 
 #
@@ -91,7 +90,7 @@ def load_profiles(profiles, parser="/sbin/apparmor_parser", args=['-r', '--write
     command.extend(profiles)
     rc, output = easyprof.cmd(command)
     if rc != 0:
-         raise AppArmorException("policy load failed with errno %d: %s" %(rc, output))
+        raise AppArmorException("policy load failed with errno %d: %s" %(rc, output))
     return (rc, output)
 
 #
@@ -126,11 +125,11 @@ def unload_profiles(profiles):
 #
 # adjust easyprof output_policy to behave like this
 #
-def output_policy(easyp, params, count, dir, force=True):
+def output_policy(easyp, params, count, destdir, force=True):
     '''Output policy'''
     policy = easyp.gen_policy(**params)
     out_fn = None
-    if not dir:
+    if not destdir:
         if count:
             sys.stdout.write('### aa-easyprof profile #%d ###\n' % count)
         sys.stdout.write('%s\n' % policy)
@@ -144,16 +143,16 @@ def output_policy(easyp, params, count, dir, force=True):
             raise AppArmorException("Could not determine output filename")
 
         # Generate an absolute path, convertng any path delimiters to '.'
-        out_fn = os.path.join(dir, out_fn.profilename)
+        out_fn = os.path.join(destdir, out_fn.profilename)
         # we differ here in that we want to overwrite if exists
         if not force and os.path.exists(out_fn):
             raise AppArmorException("'%s' already exists" % out_fn)
 
-        if not os.path.exists(dir):
-            os.mkdir(dir)
+        if not os.path.exists(destdir):
+            os.mkdir(destdir)
 
-        if not os.path.isdir(dir):
-            raise AppArmorException("'%s' is not a directory" % dir)
+        if not os.path.isdir(destdir):
+            raise AppArmorException("'%s' is not a directory" % destdir)
 
         f, fn = tempfile.mkstemp(prefix='aa-easyprof')
         if not isinstance(policy, bytes):
@@ -177,7 +176,7 @@ def get_package_manifest(hooklink, pkg):
     '''follow a click hook manifest symlink and return the main package manifest location'''
 
     json_dir = os.path.realpath(os.path.normpath(os.path.join(os.path.dirname(hooklink), os.readlink(hooklink))))
-    manifest_name = "%s.manifest" %(pkg) 
+    manifest_name = "%s.manifest" % pkg
 
     # walk up the tree to find the .click directory, then grab
     # info/manifest from below that
@@ -192,14 +191,13 @@ def get_package_manifest(hooklink, pkg):
 def get_click_dir(pkg_dir, pkg, ver):
     (p, last) = os.path.split(pkg_dir)
     if not ver == last:
-        raise AppArmorException("package version dir '%s' does not match expected '%s'" %s(pkg_dir, ver))
+        raise AppArmorException("package version dir '%s' does not match expected '%s'" %(pkg_dir, ver))
     (result, last) = os.path.split(p)
     if not pkg == last:
         raise AppArmorException("package dir '%s' does not match expected '%s'" %(p, pkg))
     return result
 
 required_click_fields = ["name", "version"]
-required_apparmor_fields = ["policy_groups", "policy_version"]
 
 def read_click_manifest(manifest):
     f = open(manifest, "r")
@@ -214,9 +212,8 @@ def read_apparmor_manifest(manifest, app):
     j = json.load(f)
     if (len(j.keys()) == 1) and app in j:
         j = j[app]
-    for field in required_apparmor_fields:
-        if not field in j:
-            raise AppArmorException("could not find required field '%s' in json" %(field))
+    # no fields are actually required, the framework transformation
+    # should set sensible defaults if any/all are missing
     return j
 
 class ClickManifest(object):
@@ -240,8 +237,6 @@ class ClickManifest(object):
         # FIXME: note that at some point in the future this may get
         # overridden by the package manifest entry, if defined
         self.click_dir = get_click_dir(pkg_dir, package, version)
-        # security = json['security']
-        # self.profiles = security['profiles']
 
 class EasyprofManifest(object):
     def __init__(self):
@@ -252,8 +247,8 @@ class EasyprofManifest(object):
         self.manifest['profiles'][name] = profile
 
 class AppName(object):
-    _CLICK_PREFIX="click_"
-    _CLICK_SUFFIX=".json"
+    _CLICK_PREFIX = "click_"
+    _CLICK_SUFFIX = ".json"
 
     def __init__(self, clickname=None, profilename=None, rawname=None):
         # verify valid click tuple name?
@@ -336,6 +331,13 @@ class EasyprofProfile(object):
 # ubuntu 13.10 tranformation function takes a click manifest json
 # structure as input and returns an aa-easyprof json manifest
 
+defaults_profile = {
+    'template': 'ubuntu-sdk',
+    'policy_version': '1.0',
+    'policy_vendor': 'ubuntu',
+    'policy_groups': list(),
+}
+
 def ubuntu_1310_transform(click_manifest):
     '''Ubuntu 13.10 SDK framework transformation function'''
     m = EasyprofManifest()
@@ -345,6 +347,9 @@ def ubuntu_1310_transform(click_manifest):
         newname = "%s_%s_%s" %(click_manifest.appname, p, click_manifest.version)
 
         profile = click_manifest.profiles[p]
+        for default in defaults_profile:
+            if not default in profile:
+                profile[default] = defaults_profile[default]
 
         if 'template' in profile:
             newp.template = profile['template']
@@ -370,6 +375,7 @@ def ubuntu_1310_transform(click_manifest):
 
     return m.manifest
 
+
 # these define the transformation funtions given a specific framework
 # definition in the ClickManifest file. This may need to grow more
 # complex depending on how the framework definition grows in click
