@@ -10,6 +10,9 @@
 #
 # ------------------------------------------------------------------
 
+# not needed for python3, but pyflakes is grumpy without it
+from __future__ import print_function
+
 from apparmor import click
 from apparmor.click import AppName
 import apparmor.easyprof
@@ -252,13 +255,74 @@ class T(unittest.TestCase):
 
         try:
             cm = apparmor.click.ClickManifest(os.path.join(c.click_dir, "com.ubuntu.developer.username.myapp_sample-app_0.1.json"))
-            easyprof_manifest = apparmor.click.transform(cm)
+            apparmor.click.transform(cm)
         except click.AppArmorException:
             return
         except Exception:
             raise
         raise Exception ("Framework should be invalid")
 
+    # the security policy is supposed to have a policy_groups entry even
+    # if the list inside it is empty. However, I'm seeing click apps
+    # without it so we'll accept it and move_on
+    # 
+    # 
+    def test_parse_security_manifest_no_policy_groups(self):
+        '''test being given a symlink and parsing the manifests, leniently'''
+        c = self.clickstate
+        package = "com.ubuntu.developer.username.yourapp"
+        c.add_package(package, "0.3")
+        security_json='{ "policy_version": "1.0" }'
+        c.add_app('sample-app', manifest=security_json)
+
+        cm = apparmor.click.ClickManifest(os.path.join(c.click_dir, "%s_sample-app_0.3.json" %(package)))
+        easyprof_manifest = apparmor.click.transform(cm)
+
+        expected = json.loads('''{
+  "profiles": {
+    "%s_sample-app_0.3": {
+      "policy_groups": [ ],
+      "policy_vendor": "ubuntu",
+      "policy_version": "1.0",
+      "template": "ubuntu-sdk",
+      "template_variables": {
+        "APPNAME": "%s",
+        "APPVERSION": "0.3",
+        "CLICK_DIR": "%s"
+      }
+    }
+  }
+}''' %(package, package, c.packages_tree))
+        self.assertEquals(expected, easyprof_manifest, "Expected to get %s, got %s" %(expected, easyprof_manifest))
+
+    def test_parse_security_manifest_no_entries(self):
+        '''test being given a symlink and parsing the manifests, no policy whatsoever'''
+        c = self.clickstate
+        package = "com.ubuntu.newbie.username.yourapp"
+        c.add_package(package, "0.3")
+        security_json='{ }'
+        c.add_app('sample-app', manifest=security_json)
+
+        cm = apparmor.click.ClickManifest(os.path.join(c.click_dir, "%s_sample-app_0.3.json" %(package)))
+        easyprof_manifest = apparmor.click.transform(cm)
+
+        expected = json.loads('''{
+  "profiles": {
+    "%s_sample-app_0.3": {
+      "policy_groups": [ ],
+      "policy_vendor": "ubuntu",
+      "policy_version": "1.0",
+      "template": "ubuntu-sdk",
+      "template_variables": {
+        "APPNAME": "%s",
+        "APPVERSION": "0.3",
+        "CLICK_DIR": "%s"
+      }
+    }
+  }
+}''' %(package, package, c.packages_tree))
+        self.assertEquals(expected, easyprof_manifest, "Expected to get %s, got %s" %(expected, easyprof_manifest))
+
     def test_parse_security_manifest_unconfined(self):
         '''test being given a symlink and parsing the manifests for an unconfined app'''
 
@@ -304,7 +368,7 @@ class T(unittest.TestCase):
 }"""
         json_in = json.loads(rawinput)
         try:
-            json_out = click.transform(json_in)
+            click.transform(json_in)
         except click.AppArmorException:
             return
         except Exception:
@@ -326,7 +390,7 @@ class T(unittest.TestCase):
 }"""
         json_in = json.loads(rawinput)
         try:
-            json_out = click.transform(json_in)
+            click.transform(json_in)
         except click.AppArmorException:
             return
         except Exception:
@@ -345,7 +409,7 @@ class T(unittest.TestCase):
 }"""
         json_in = json.loads(rawinput)
         try:
-            json_out = click.transform(json_in)
+            click.transform(json_in)
         except click.AppArmorException:
             return
         except Exception:
